* Add stricmp function to lib_generic/string.c for architectures
  that are missing it.
  Patch by Alan J. Luse, 02 May 2006


--- u-boot-1.1.4.orig/lib_generic/string.c	2005-12-16 09:39:27.000000000 -0700
+++ u-boot-1.1.4/lib_generic/string.c	2006-05-02 09:57:26.667996000 -0700
@@ -20,6 +20,36 @@
 #include <linux/ctype.h>
 #include <malloc.h>

+#ifndef __HAVE_ARCH_STRICMP
+/**
+ * stricmp - Case insensitive string comparison.
+ * @s1: One string
+ * @s2: The other string
+ */
+int stricmp(const char *s1, const char *s2)
+{
+	/* Yes, Virginia, it had better be unsigned */
+	unsigned char c1, c2;
+
+	c1 = 0;	c2 = 0;
+	do {
+		c1 = *s1; c2 = *s2;
+		s1++; s2++;
+		if (!c1)
+			break;
+		if (!c2)
+			break;
+		if (c1 == c2)
+			continue;
+		c1 = tolower(c1);
+		c2 = tolower(c2);
+		if (c1 != c2)
+			break;
+	} while (1);
+
+	return (int)c1 - (int)c2;
+}
+#endif

 #ifndef __HAVE_ARCH_STRNICMP
 /**

--- u-boot-1.1.4.orig/include/linux/string.h	2005-12-16 09:39:27.000000000 -0700
+++ u-boot-1.1.4/include/linux/string.h	2005-09-01 14:18:41.510245100 -0700
@@ -38,6 +38,9 @@ extern int strcmp(const char *,const cha
 #ifndef __HAVE_ARCH_STRNCMP
 extern int strncmp(const char *,const char *,__kernel_size_t);
 #endif
+#ifndef __HAVE_ARCH_STRICMP
+extern int stricmp(const char *, const char *);
+#endif
 #ifndef __HAVE_ARCH_STRNICMP
 extern int strnicmp(const char *, const char *, __kernel_size_t);
 #endif
